@@ -1,5 +1,5 @@
 package Authorization::RBAC;
-$Authorization::RBAC::VERSION = '0.09';
+$Authorization::RBAC::VERSION = '0.10';
 use utf8;
 use Moose;
 with 'MooseX::Object::Pluggable';
@@ -35,6 +35,12 @@ has conf => ( is => 'rw',
               }
             );
 
+# optional (used by DBIX backend )
+has 'schema'     => (
+                     is        => 'rw',
+                     predicate => 'has_schema',
+                 );
+
 has 'debug' => (
                 is       => 'rw',
                );
@@ -83,7 +89,7 @@ sub can_access {
     # Not necessary to check if it's not an object
     next if ! ref($obj);
 
-    # copy obj not to disturb objets
+    # copy obj to not disturb objets
     my $obj2 = $obj;
 
     # build parent objects
@@ -112,7 +118,7 @@ sub can_access {
             $ops = $additional_operations;
         }
         else {
-            $ops = '';
+            $ops = [];
         }
         if ( ! $self->check_permission( $roles, $obj2, $ops )){
             $self->_log("return 0");
@@ -136,8 +142,6 @@ sub check_permission {
   my @ops_to_access = $obj->ops_to_access;
   if ( $additional_operations ) {
       push(@ops_to_access, $self->get_operations($additional_operations));
-
-      my @toto=$self->get_operations($additional_operations);
   }
 
   $self->_log("  [OK] Object is not protected") if ( ! $ops_to_access[0] );
@@ -154,25 +158,26 @@ sub check_permission {
       my $ret = 0;
       ROLES: foreach my $r ( @$roles ) {
 
-      $self->_log("- Search if role " . $r->name ." can '" . $op->name . "' '${typeobj}_" . $obj->id."'");
+            next if ! $r;
+            $self->_log("- Search if role " . $r->name ." can '" . $op->name . "' '${typeobj}_" . $obj->id."'");
 
-      # get permission from backend
-      my ($result, $inheritable) = $self->get_permission($r, $op, $obj);
+            # get permission from backend
+            my ($result, $inheritable) = $self->get_permission($r, $op, $obj);
 
-      if ( ! defined $result ) {
-        next;
-      }
-      elsif ( ! $result ) {
-        $self->_log( "  [KO] ".$r->name." cannot '" . $op->name . "' '${typeobj}_" . $obj->id."'" );
-        $ret = 0;
-      }
-      elsif ( $result ) {
-        $self->_log( "  [OK] ".$r->name." can '" . $op->name . "' '${typeobj}_" . $obj->id."'" );
-        $ret = 1;
-        last ROLES;
-      }
-  }
-    return 0 if ! $ret;
+            if ( ! defined $result ) {
+                next;
+            }
+            elsif ( ! $result ) {
+                $self->_log( "  [KO] ".$r->name." cannot '" . $op->name . "' '${typeobj}_" . $obj->id."'" );
+                $ret = 0;
+            }
+            elsif ( $result ) {
+                $self->_log( "  [OK] ".$r->name." can '" . $op->name . "' '${typeobj}_" . $obj->id."'" );
+                $ret = 1;
+                last ROLES;
+            }
+        }
+      return 0 if ! $ret;
   }
 
   return 1;
@@ -198,14 +203,14 @@ Authorization::RBAC - Role-Based Access Control system
 
 =head1 VERSION
 
-version 0.09
+version 0.10
 
 =head1 SYNOPSIS
 
     use Authorization::RBAC;
 
     my $conf = 't/conf/permsfromdbix.yml';
-    my $rbac = Authorization::RBAC->new( conf => $conf );
+    my $rbac = Authorization::RBAC->new( conf => $conf ); # add schema => $schema if DBIx backend
 
     my $page  = $rbac->schema->resultset('Page')->search( name => 'add' , parent => 7 );
     my $roles = ... function that returns the roles ...
